/* This testcase is part of GDB, the GNU debugger.

   Copyright 2022-2025 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
class
base {
public:
  int member;
};

class complete: public base { };

class incomplete: public base { };

complete comp;
complete *cp = &comp;
incomplete *inc;
int *ip;

int
foo (base* b)
{
    asm ("foo_label: .globl foo_label");
    return 1;
}

int
main (void)
{
    asm("main_label: .globl main_label");
    comp.member = 0;
    return 0;
}
